[python-pyraf] 01/04: Upstream version 2.1.6

Ole Streicher olebole-guest at moszumanska.debian.org
Fri Jan 31 17:04:54 UTC 2014


This is an automated email from the git hooks/post-receive script.

olebole-guest pushed a commit to branch debian
in repository python-pyraf.

commit e9519c665b94034dffd5e8e6ae73418e67335c98
Author: Ole Streicher <debian at liska.ath.cx>
Date:   Fri Jan 31 17:54:07 2014 +0100

    Upstream version 2.1.6
---
 PKG-INFO                                           |   2 +-
 lib/pyraf.egg-info/PKG-INFO                        |   2 +-
 lib/pyraf/ipython_api.py                           |  43 ++++++++++++++-------
 lib/pyraf/version.py                               |  20 +++++-----
 lib/pyraf/version.py.orig1                         |  16 ++++----
 lib/pyraf/version.py.orig2                         |  16 ++++----
 lib/pyraf/wutil.py                                 |  14 +++++--
 lib/pyraf_setup.pyc                                | Bin 3295 -> 3295 bytes
 required_pkgs/stsci.distutils/CHANGES.txt          |  10 ++++-
 required_pkgs/stsci.distutils/setup.cfg            |   4 +-
 .../stsci.distutils/stsci/distutils/release.py     |   3 ++
 .../stsci/distutils/versionutils.py                |  10 +++--
 .../stsci.tools/lib/stsci/tools/__init__.py        |   3 +-
 .../stsci.tools/lib/stsci/tools/capable.py         |   4 +-
 .../stsci.tools/lib/stsci/tools/eparoption.py      |  32 +++++++++++++--
 .../stsci.tools/lib/stsci/tools/filedlg.py         |   3 +-
 .../stsci.tools/lib/stsci/tools/fileutil.py        |  18 ++++-----
 .../stsci.tools/lib/stsci/tools/tester.py          |  14 +++----
 .../lib/stsci/tools/tests/testStpyfits.py          |  18 ++++-----
 required_pkgs/stsci.tools/setup.cfg                |   2 +-
 required_pkgs/stsci.tools/setup.cfg.orig           |   2 +-
 scripts/pyraf                                      |  10 +++--
 setup.cfg                                          |   4 +-
 tools/createTarBall.csh                            |   8 ++--
 24 files changed, 163 insertions(+), 95 deletions(-)

diff --git a/PKG-INFO b/PKG-INFO
index 53a3460..23d85b8 100644
--- a/PKG-INFO
+++ b/PKG-INFO
@@ -1,6 +1,6 @@
 Metadata-Version: 1.1
 Name: pyraf
-Version: 2.1.5
+Version: 2.1.6
 Summary: Provides a Pythonic interface to IRAF that can be used in place of
 the existing IRAF CL
 Home-page: http://www.stsci.edu/resources/software_hardware/pyraf
diff --git a/lib/pyraf.egg-info/PKG-INFO b/lib/pyraf.egg-info/PKG-INFO
index 53a3460..23d85b8 100644
--- a/lib/pyraf.egg-info/PKG-INFO
+++ b/lib/pyraf.egg-info/PKG-INFO
@@ -1,6 +1,6 @@
 Metadata-Version: 1.1
 Name: pyraf
-Version: 2.1.5
+Version: 2.1.6
 Summary: Provides a Pythonic interface to IRAF that can be used in place of
 the existing IRAF CL
 Home-page: http://www.stsci.edu/resources/software_hardware/pyraf
diff --git a/lib/pyraf/version.py b/lib/pyraf/version.py
index 271378f..3a51d55 100644
--- a/lib/pyraf/version.py
+++ b/lib/pyraf/version.py
@@ -7,14 +7,14 @@ __all__ = ['__version__', '__vdate__', '__svn_revision__', '__svn_full_info__',
 
 import datetime
 
-__version__ = '2.1.5'
+__version__ = '2.1.6'
 __vdate__ = 'unspecified'
-__svn_revision__ = "2095"
+__svn_revision__ = "2135"
 __svn_full_info__ = 'unknown'
-__setup_datetime__ = datetime.datetime(2013, 11, 25, 12, 17, 10, 987591)
+__setup_datetime__ = datetime.datetime(2014, 1, 28, 23, 55, 42, 271373)
 
 # what version of stsci.distutils created this version.py
-stsci_distutils_version = '0.3.7.dev27596'
+stsci_distutils_version = '0.3.7'
 
 if '.dev' in __version__:
     def update_svn_info():
@@ -35,9 +35,10 @@ if '.dev' in __version__:
             pipe = subprocess.Popen(['svn', 'info', path],
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.PIPE)
-            if pipe.wait() == 0:
+            stdout, _ = pipe.communicate()
+            if pipe.returncode == 0:
                 lines = []
-                for line in pipe.stdout.readlines():
+                for line in stdout.splitlines():
                     line = line.decode('latin1').strip()
                     if not line:
                         continue
@@ -65,10 +66,11 @@ if '.dev' in __version__:
                 pipe = subprocess.Popen(['svnversion', path],
                                         stdout=subprocess.PIPE,
                                         stderr=subprocess.PIPE)
-                if pipe.wait() == 0:
-                    stdout = pipe.stdout.read().decode('latin1').strip()
+                stdout, _ = pipe.communicate()
+                if pipe.returncode == 0:
+                    stdout = stdout.decode('latin1').strip()
                     if stdout and stdout[0] in string.digits:
-                        __svn_revision__ = "2095"
+                        __svn_revision__ = "2135"
             except OSError:
                 pass
 
diff --git a/lib/pyraf/version.py.orig1 b/lib/pyraf/version.py.orig1
index 37f8de0..ac2ec2d 100644
--- a/lib/pyraf/version.py.orig1
+++ b/lib/pyraf/version.py.orig1
@@ -7,14 +7,14 @@ __all__ = ['__version__', '__vdate__', '__svn_revision__', '__svn_full_info__',
 
 import datetime
 
-__version__ = '2.1.5'
+__version__ = '2.1.6'
 __vdate__ = 'unspecified'
 __svn_revision__ = 'Unable to determine SVN revision'
 __svn_full_info__ = 'unknown'
-__setup_datetime__ = datetime.datetime(2013, 11, 25, 12, 17, 2, 831411)
+__setup_datetime__ = datetime.datetime(2014, 1, 28, 23, 55, 36, 61914)
 
 # what version of stsci.distutils created this version.py
-stsci_distutils_version = '0.3.7.dev27596'
+stsci_distutils_version = '0.3.7'
 
 if '.dev' in __version__:
     def update_svn_info():
@@ -35,9 +35,10 @@ if '.dev' in __version__:
             pipe = subprocess.Popen(['svn', 'info', path],
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.PIPE)
-            if pipe.wait() == 0:
+            stdout, _ = pipe.communicate()
+            if pipe.returncode == 0:
                 lines = []
-                for line in pipe.stdout.readlines():
+                for line in stdout.splitlines():
                     line = line.decode('latin1').strip()
                     if not line:
                         continue
@@ -65,8 +66,9 @@ if '.dev' in __version__:
                 pipe = subprocess.Popen(['svnversion', path],
                                         stdout=subprocess.PIPE,
                                         stderr=subprocess.PIPE)
-                if pipe.wait() == 0:
-                    stdout = pipe.stdout.read().decode('latin1').strip()
+                stdout, _ = pipe.communicate()
+                if pipe.returncode == 0:
+                    stdout = stdout.decode('latin1').strip()
                     if stdout and stdout[0] in string.digits:
                         __svn_revision__ = stdout
             except OSError:
diff --git a/lib/pyraf/version.py.orig2 b/lib/pyraf/version.py.orig2
index 24451b7..1c68236 100644
--- a/lib/pyraf/version.py.orig2
+++ b/lib/pyraf/version.py.orig2
@@ -7,14 +7,14 @@ __all__ = ['__version__', '__vdate__', '__svn_revision__', '__svn_full_info__',
 
 import datetime
 
-__version__ = '2.1.5'
+__version__ = '2.1.6'
 __vdate__ = 'unspecified'
 __svn_revision__ = 'Unable to determine SVN revision'
 __svn_full_info__ = 'unknown'
-__setup_datetime__ = datetime.datetime(2013, 11, 25, 12, 17, 2, 831411)
+__setup_datetime__ = datetime.datetime(2014, 1, 28, 23, 55, 36, 61914)
 
 # what version of stsci.distutils created this version.py
-stsci_distutils_version = '0.3.7.dev27596'
+stsci_distutils_version = '0.3.7'
 
 if '.dev' in __version__:
     def update_svn_info():
@@ -35,9 +35,10 @@ if '.dev' in __version__:
             pipe = subprocess.Popen(['svn', 'info', path],
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.PIPE)
-            if pipe.wait() == 0:
+            stdout, _ = pipe.communicate()
+            if pipe.returncode == 0:
                 lines = []
-                for line in pipe.stdout.readlines():
+                for line in stdout.splitlines():
                     line = line.decode('latin1').strip()
                     if not line:
                         continue
@@ -65,8 +66,9 @@ if '.dev' in __version__:
                 pipe = subprocess.Popen(['svnversion', path],
                                         stdout=subprocess.PIPE,
                                         stderr=subprocess.PIPE)
-                if pipe.wait() == 0:
-                    stdout = pipe.stdout.read().decode('latin1').strip()
+                stdout, _ = pipe.communicate()
+                if pipe.returncode == 0:
+                    stdout = stdout.decode('latin1').strip()
                     if stdout and stdout[0] in string.digits:
                         __svn_revision__ = stdout
             except OSError:
diff --git a/lib/pyraf/wutil.py b/lib/pyraf/wutil.py
index cbbf3ab..70c67eb 100644
--- a/lib/pyraf/wutil.py
+++ b/lib/pyraf/wutil.py
@@ -4,7 +4,7 @@ These are python stubs that are overloaded by a c version implementations.
 If the c versions do not exist, then these routines will do nothing
 
 
-$Id: wutil.py 2069 2013-10-09 15:33:36Z sontag $
+$Id: wutil.py 2119 2013-12-31 20:44:39Z sontag $
 """
 from __future__ import division # confidence high
 
@@ -508,17 +508,19 @@ def dumpspecs(outstream = None, skip_volatiles = False):
        pass
 
     out = "python exec = "+str(sys.executable)
-    out += "\npython ver = "+str(sys.version)
+    out += "\npython ver = "+sys.version.split()[0]
     out += "\nplatform = "+str(sys.platform)
     if not skip_volatiles:
         out += "\nPyRAF ver = "+pyrver
     out += "\nPY3K = "+str(capable.PY3K)
     out += "\nc.OF_GRAPHICS = "+str(capable.OF_GRAPHICS)
+    dco = 'not yet known'
     if hasattr(capable, 'get_dc_owner'): # rm hasattr at/after v2.2
         if skip_volatiles:
             out +="\n/dev/console owner = <skipped>"
         else:
-            out +="\n/dev/console owner = "+str(capable.get_dc_owner(False, True))
+            dco = capable.get_dc_owner(False, True)
+            out +="\n/dev/console owner = "+str(dco)
 
     if not capable.OF_GRAPHICS:
         if hasattr(capable, 'TKINTER_IMPORT_FAILED'):
@@ -541,6 +543,12 @@ def dumpspecs(outstream = None, skip_volatiles = False):
         out += "\nimported aqutil = "+str(bool(_has_aqutil))
         out += "\nimported xutil = "+str(bool(_has_xutil))
 
+        # Case of WUTIL_USING_X and not _has_xutil means either they don't have
+        # xutil library installed, or they do but they can't draw to screen
+        if WUTIL_USING_X and capable.OF_GRAPHICS and \
+           not _skipDisplay and not bool(_has_xutil):
+            # quick debug help here for case where xutil didn't build
+            out += '\n\tWARNING!  PyRAF may be missing the "xutil" library. See PyRAF FAQ 1.9'
         if 'PYRAFGRAPHICS' in os.environ:
             val = os.environ['PYRAFGRAPHICS']
             out += "\nPYRAFGRAPHICS = "+val
diff --git a/lib/pyraf_setup.pyc b/lib/pyraf_setup.pyc
index 46bda3a..e91e557 100644
Binary files a/lib/pyraf_setup.pyc and b/lib/pyraf_setup.pyc differ
diff --git a/required_pkgs/stsci.distutils/CHANGES.txt b/required_pkgs/stsci.distutils/CHANGES.txt
index 3bce7ad..c9a6b2c 100644
--- a/required_pkgs/stsci.distutils/CHANGES.txt
+++ b/required_pkgs/stsci.distutils/CHANGES.txt
@@ -1,12 +1,20 @@
 Changelog
 ===========
 
-0.3.7 (unreleased)
+0.3.8 (unreleased)
 ------------------
 
 - Nothing changed yet.
 
 
+0.3.7 (2013-12-23)
+------------------
+
+- Avoid using ``Popen.stdout`` directly in the version.py SVN revision
+  auto-update script to avoid possible ResourceWarnings on Python >= 3.2.
+  See https://github.com/spacetelescope/PyFITS/issues/45
+
+
 0.3.6 (2013-11-21)
 ------------------
 
diff --git a/required_pkgs/stsci.distutils/setup.cfg b/required_pkgs/stsci.distutils/setup.cfg
index f5240c5..999f7a0 100644
--- a/required_pkgs/stsci.distutils/setup.cfg
+++ b/required_pkgs/stsci.distutils/setup.cfg
@@ -1,6 +1,6 @@
 [metadata]
 name = stsci.distutils
-version = 0.3.7.dev
+version = 0.3.8.dev
 author = Erik M. Bray
 author-email = embray at stsci.edu
 home-page = http://www.stsci.edu/resources/software_hardware/stsci_python
@@ -41,7 +41,5 @@ zip-safe = False
 [entry_points]
 zest.releaser.releaser.before =
     fix_sdist_format = stsci.distutils.release:fix_sdist_format
-zest.releaser.releaser.after =
-    add_to_stsci_package_index = stsci.distutils.release:add_to_stsci_package_index
 zest.releaser.postreleaser.before =
     fix_dev_version_template = stsci.distutils.release:fix_dev_version_template
diff --git a/required_pkgs/stsci.distutils/stsci/distutils/release.py b/required_pkgs/stsci.distutils/stsci/distutils/release.py
index 7a75b14..e39df5f 100644
--- a/required_pkgs/stsci.distutils/stsci/distutils/release.py
+++ b/required_pkgs/stsci.distutils/stsci/distutils/release.py
@@ -76,6 +76,9 @@ def fix_sdist_format(data):
     Releaser._sdist_options = _my_sdist_options
 
 
+# TODO: This package index is no longer being maintained, so this hook can
+# be removed in the next version or so.  I don't think anyone is using it
+# though.
 def add_to_stsci_package_index(data):
     """
     A releaser.after hook to copy the source distribution to STScI's local
diff --git a/required_pkgs/stsci.distutils/stsci/distutils/versionutils.py b/required_pkgs/stsci.distutils/stsci/distutils/versionutils.py
index e4b3eac..8429db1 100644
--- a/required_pkgs/stsci.distutils/stsci/distutils/versionutils.py
+++ b/required_pkgs/stsci.distutils/stsci/distutils/versionutils.py
@@ -52,9 +52,10 @@ if '.dev' in __version__:
             pipe = subprocess.Popen(['svn', 'info', path],
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.PIPE)
-            if pipe.wait() == 0:
+            stdout, _ = pipe.communicate()
+            if pipe.returncode == 0:
                 lines = []
-                for line in pipe.stdout.readlines():
+                for line in stdout.splitlines():
                     line = line.decode('latin1').strip()
                     if not line:
                         continue
@@ -82,8 +83,9 @@ if '.dev' in __version__:
                 pipe = subprocess.Popen(['svnversion', path],
                                         stdout=subprocess.PIPE,
                                         stderr=subprocess.PIPE)
-                if pipe.wait() == 0:
-                    stdout = pipe.stdout.read().decode('latin1').strip()
+                stdout, _ = pipe.communicate()
+                if pipe.returncode == 0:
+                    stdout = stdout.decode('latin1').strip()
                     if stdout and stdout[0] in string.digits:
                         __svn_revision__ = stdout
             except OSError:
diff --git a/required_pkgs/stsci.tools/lib/stsci/tools/__init__.py b/required_pkgs/stsci.tools/lib/stsci/tools/__init__.py
index 7d1e4b6..7defa85 100644
--- a/required_pkgs/stsci.tools/lib/stsci/tools/__init__.py
+++ b/required_pkgs/stsci.tools/lib/stsci/tools/__init__.py
@@ -1,5 +1,4 @@
-# from __future__ import absolute_import
-from __future__ import division # confidence high
+from __future__ import division  # confidence high
 
 from .version import *
 
diff --git a/required_pkgs/stsci.tools/lib/stsci/tools/capable.py b/required_pkgs/stsci.tools/lib/stsci/tools/capable.py
index 975c90a..a58ce4e 100644
--- a/required_pkgs/stsci.tools/lib/stsci/tools/capable.py
+++ b/required_pkgs/stsci.tools/lib/stsci/tools/capable.py
@@ -3,7 +3,7 @@ This is meant to be fast and light, having no complicated dependencies, so
 that any module can fearlessly import this without adverse affects or
 performance concerns.
 
-$Id: capable.py 26617 2013-09-10 03:54:22Z sontag $
+$Id: capable.py 27599 2013-11-27 17:20:58Z sontag $
 """
 
 from __future__ import division # confidence high
@@ -68,7 +68,7 @@ def get_dc_owner(raises, mask_if_self):
             return "<self>"
         owner_name = getpwuid(owner_uid).pw_name
         return owner_name
-    except Exception, e:
+    except Exception as e:
         if raises:
             raise e
         else:
diff --git a/required_pkgs/stsci.tools/lib/stsci/tools/eparoption.py b/required_pkgs/stsci.tools/lib/stsci/tools/eparoption.py
index a6d218f..957ab46 100644
--- a/required_pkgs/stsci.tools/lib/stsci/tools/eparoption.py
+++ b/required_pkgs/stsci.tools/lib/stsci/tools/eparoption.py
@@ -17,7 +17,7 @@
 
    Enumerated lists - Menubutton/Menu widget
 
-$Id: eparoption.py 16939 2012-05-23 13:36:09Z sontag $
+$Id: eparoption.py 28952 2014-01-14 15:57:36Z lim $
 
 M.D. De La Pena, 1999 August 05
 """
@@ -395,9 +395,19 @@ class EparOption(object):
 
         self.menu = Menu(self.entry, tearoff = 0)
         if self.browserEnabled != DISABLED:
-            self.menu.add_command(label   = "File Browser",
-                                  state   = self.browserEnabled,
-                                  command = self.fileBrowser)
+            # Handle file and directory in different functions (tkFileDialog)
+            if capable.OF_TKFD_IN_EPAR:
+                self.menu.add_command(label   = "File Browser",
+                                      state   = self.browserEnabled,
+                                      command = self.fileBrowser)
+                self.menu.add_command(label   = "Directory Browser",
+                                      state   = self.browserEnabled,
+                                      command = self.dirBrowser)
+            # Handle file and directory in the same function (filedlg)
+            else:
+                self.menu.add_command(label   = "File/Directory Browser",
+                                      state   = self.browserEnabled,
+                                      command = self.fileBrowser)
             self.menu.add_separator()
         self.menu.add_command(label   = "Clear",
                               state   = self.clearEnabled,
@@ -439,6 +449,20 @@ class EparOption(object):
         # accidentally typing over the filename
         self.lastSelection = None
 
+    def dirBrowser(self):
+        """Invoke a Tkinter directory dialog"""
+        if capable.OF_TKFD_IN_EPAR:
+            fname = tkFileDialog.askdirectory(parent=self.entry,
+                                              title="Select Directory")
+        else:
+            raise NotImplementedError('Fix popupChoices() logic.')
+        if not fname: return # canceled
+
+        self.choice.set(fname)
+        # don't select when we go back to widget to reduce risk of
+        # accidentally typing over the filename
+        self.lastSelection = None
+
     def clearEntry(self):
         """Clear just this Entry"""
         self.entry.delete(0, END)
diff --git a/required_pkgs/stsci.tools/lib/stsci/tools/filedlg.py b/required_pkgs/stsci.tools/lib/stsci/tools/filedlg.py
index b274335..4f4f333 100644
--- a/required_pkgs/stsci.tools/lib/stsci/tools/filedlg.py
+++ b/required_pkgs/stsci.tools/lib/stsci/tools/filedlg.py
@@ -18,7 +18,7 @@
 #               F.DialogCleanup()
 ####
 """
-$Id: filedlg.py 20343 2012-11-09 17:07:48Z sontag $
+$Id: filedlg.py 28952 2014-01-14 15:57:36Z lim $
 """
 from __future__ import division # confidence high
 
@@ -173,6 +173,7 @@ class FileDialog(ModalDialog):
         self.dirLb = Listbox(frame, {'yscroll':scrollBar.set})
         self.dirLb.pack({'expand':'yes', 'side' :'top', 'pady' :'1',
                 'fill' :'both'})
+        self.dirLb.bind('<1>', self.DoSelection)
         self.dirLb.bind('<Double-Button-1>', self.DoDoubleClickDir)
         scrollBar['command'] = self.dirLb.yview
 
diff --git a/required_pkgs/stsci.tools/lib/stsci/tools/fileutil.py b/required_pkgs/stsci.tools/lib/stsci/tools/fileutil.py
index de4a01c..82cbab1 100644
--- a/required_pkgs/stsci.tools/lib/stsci/tools/fileutil.py
+++ b/required_pkgs/stsci.tools/lib/stsci/tools/fileutil.py
@@ -676,11 +676,11 @@ def openImage(filename,mode='readonly',memmap=0,writefits=True,clobber=True,fits
                     if dqexists:
                         print 'Writing out WAIVERED as MEF to ',dqfitsname
                         dqfile.writeto(dqfitsname, clobber=clobber)
-            # Now close input GEIS image, and open writable
-            # handle to output FITS image instead...
-            fimg.close()
-            del fimg
-            fimg = pyfits.open(fitsname,mode=mode,memmap=memmap)
+                # Now close input GEIS image, and open writable
+                # handle to output FITS image instead...
+                fimg.close()
+                del fimg
+                fimg = pyfits.open(fitsname,mode=mode,memmap=memmap)
 
         # Return handle for use by user
         return fimg
@@ -807,7 +807,7 @@ def getExtn(fimg,extn=None):
     """
     # If no extension is provided, search for first extension
     # in FITS file with data associated with it.
-    if not extn:
+    if extn is None:
         # Set up default to point to PRIMARY extension.
         _extn = fimg[0]
         # then look for first extension with data.
@@ -843,8 +843,10 @@ def getExtn(fimg,extn=None):
             _indx = str(extn[:extn.find('/')])
             _extn = fimg[int(_indx)]
         elif type(extn) == types.StringType:
+            if extn.strip() == '':
+                _extn = None # force error since invalid name was provided
             # Only one extension value specified...
-            if extn.isdigit():
+            elif extn.isdigit():
                 # We only have an extension number specified as a string...
                 _nextn = int(extn)
             else:
@@ -1410,5 +1412,3 @@ def _expand1(instring, noerror):
 def access(filename):
     """Returns true if file exists"""
     return os.path.exists(Expand(filename))
-
-
diff --git a/required_pkgs/stsci.tools/lib/stsci/tools/tester.py b/required_pkgs/stsci.tools/lib/stsci/tools/tester.py
index 643fc9e..7ae9ea6 100644
--- a/required_pkgs/stsci.tools/lib/stsci/tools/tester.py
+++ b/required_pkgs/stsci.tools/lib/stsci/tools/tester.py
@@ -20,7 +20,7 @@ function to the __init__.py of their package:
 
 import stsci.tools.tester
 def test(*args,**kwds):
-    stsci.tools.tester.test(modname=__name__, *args, **kwds)
+    return stsci.tools.tester.test(modname=__name__, *args, **kwds)
 
 
 This assumes that all software packages are installed with the structure:
@@ -28,11 +28,11 @@ This assumes that all software packages are installed with the structure:
 package/
     __init__.py
     modules.py
-    test/
-    test/__init__.py
-    test/test_whatever.py
+    tests/
+    tests/__init__.py
+    tests/test_whatever.py
 
-Where the /test subdirectory containts the python files that nose will
+Where the /tests subdirectory containts the python files that nose will
 recognize as tests.
 
 """
@@ -50,7 +50,7 @@ def test(modname, mode='nose', *args, **kwds):
     Purpose:
     ========
     test: Run refcore nosetest suite of tests. The tests are located in the
-    test/ directory of the installed modules.
+    tests/ directory of the installed modules.
 
     """
 
@@ -63,7 +63,7 @@ def test(modname, mode='nose', *args, **kwds):
     else:
         raise ValueError('name of module to test not given')
 
-    DIRS = [os.path.join(curdir, testdir) for testdir in ['test', 'tests']]
+    DIRS = [os.path.join(curdir, testdir) for testdir in ['tests', 'test']]
 
     dirname = None
     for x in DIRS:
diff --git a/required_pkgs/stsci.tools/lib/stsci/tools/tests/testStpyfits.py b/required_pkgs/stsci.tools/lib/stsci/tools/tests/testStpyfits.py
index 1846126..437fea4 100644
--- a/required_pkgs/stsci.tools/lib/stsci/tools/tests/testStpyfits.py
+++ b/required_pkgs/stsci.tools/lib/stsci/tools/tests/testStpyfits.py
@@ -23,7 +23,7 @@ class TestStpyfitsFunctions(PyfitsTestCase):
 
         assert_equal(
             stpyfits.info(self.data('o4sp040b0_raw.fits'), output=False),
-            [(0, 'PRIMARY', 'PrimaryHDU', 215, (), 'int16', ''),
+            [(0, 'PRIMARY', 'PrimaryHDU', 215, (), '', ''),
              (1, 'SCI', 'ImageHDU', 141, (62, 44), 'int16', ''),
              (2, 'ERR', 'ImageHDU', 71, (62, 44), 'int16', ''),
              (3, 'DQ', 'ImageHDU', 71, (62, 44), 'int16', ''),
@@ -34,13 +34,13 @@ class TestStpyfitsFunctions(PyfitsTestCase):
 
         assert_equal(
             pyfits.info(self.data('o4sp040b0_raw.fits'), output=False),
-            [(0, 'PRIMARY', 'PrimaryHDU', 215, (), 'int16', ''),
+            [(0, 'PRIMARY', 'PrimaryHDU', 215, (), '', ''),
              (1, 'SCI', 'ImageHDU', 141, (62, 44), 'int16', ''),
-             (2, 'ERR', 'ImageHDU', 71, (), 'int16', ''),
-             (3, 'DQ', 'ImageHDU', 71, (), 'int16', ''),
+             (2, 'ERR', 'ImageHDU', 71, (), '', ''),
+             (3, 'DQ', 'ImageHDU', 71, (), '', ''),
              (4, 'SCI', 'ImageHDU', 141, (62, 44), 'int16', ''),
-             (5, 'ERR', 'ImageHDU', 71, (), 'int16', ''),
-             (6, 'DQ', 'ImageHDU', 71, (), 'int16', '')])
+             (5, 'ERR', 'ImageHDU', 71, (), '', ''),
+             (6, 'DQ', 'ImageHDU', 71, (), '', '')])
 
         assert_equal(
             stpyfits.info(self.data('cdva2.fits'), output=False),
@@ -48,7 +48,7 @@ class TestStpyfitsFunctions(PyfitsTestCase):
 
         assert_equal(
             pyfits.info(self.data('cdva2.fits'), output=False),
-            [(0, 'PRIMARY', 'PrimaryHDU', 7, (), 'int32', '')])
+            [(0, 'PRIMARY', 'PrimaryHDU', 7, (), '', '')])
 
 
     def testOpenConvienceFunction(self):
@@ -155,10 +155,10 @@ class TestStpyfitsFunctions(PyfitsTestCase):
         info3 = pyfits.info(self.temp('new1.fits'), output=False)
         info4 = stpyfits.info(self.temp('new1.fits'), output=False)
 
-        assert_equal(info1, [(0, 'PRIMARY', 'PrimaryHDU', 6, (), 'int32', '')])
+        assert_equal(info1, [(0, 'PRIMARY', 'PrimaryHDU', 6, (), '', '')])
         assert_equal(info2,
             [(0, 'PRIMARY', 'PrimaryHDU', 6, (10, 10), 'int32', '')])
-        assert_equal(info3, [(0, 'PRIMARY', 'PrimaryHDU', 6, (), 'uint8', '')])
+        assert_equal(info3, [(0, 'PRIMARY', 'PrimaryHDU', 6, (), '', '')])
         assert_equal(info4,
             [(0, 'PRIMARY', 'PrimaryHDU', 6, (10, 10), 'uint8', '')])
 
diff --git a/required_pkgs/stsci.tools/setup.cfg b/required_pkgs/stsci.tools/setup.cfg
index 00232cc..136d15f 100644
--- a/required_pkgs/stsci.tools/setup.cfg
+++ b/required_pkgs/stsci.tools/setup.cfg
@@ -1,6 +1,6 @@
 [metadata]
 name = stsci.tools
-version = 3.2.1.dev
+version = 3.2.2.dev
 author = STScI
 author-email = help at stsci.edu
 home-page = http://www.stsci.edu/resources/software_hardware/stsci_python
diff --git a/required_pkgs/stsci.tools/setup.cfg.orig b/required_pkgs/stsci.tools/setup.cfg.orig
index be12660..573de51 100644
--- a/required_pkgs/stsci.tools/setup.cfg.orig
+++ b/required_pkgs/stsci.tools/setup.cfg.orig
@@ -1,6 +1,6 @@
 [metadata]
 name = stsci.tools
-version = 3.2.1.dev
+version = 3.2.2.dev
 author = STScI
 author-email = help at stsci.edu
 home-page = http://www.stsci.edu/resources/software_hardware/stsci_python
diff --git a/scripts/pyraf b/scripts/pyraf
index 3aab382..afa409f 100755
--- a/scripts/pyraf
+++ b/scripts/pyraf
@@ -35,7 +35,7 @@ Long versions of options:
   -y  --ipython
 """
 
-# $Id: pyraf 1844 2012-10-01 19:22:00Z sontag $
+# $Id: pyraf 2120 2014-01-01 16:41:51Z sontag $
 #
 # R. White, 2000 January 21
 
@@ -159,8 +159,12 @@ if doCmdline:
            # Start the interactive shell.  Also, see IPython.embed() here:
            #     http://ipython.org/ipython-doc/stable/interactive/ \
            #     reference.html#embedding-ipython
-           from IPython.frontend.terminal.ipapp import TerminalIPythonApp
-# was:     from IPython.frontend.terminal.interactiveshell import TerminalInteractiveShell
+           try:
+              # new location of terminal as of v1.*
+              from IPython.terminal.ipapp import TerminalIPythonApp
+           except:
+              from IPython.frontend.terminal.ipapp import TerminalIPythonApp
+# was:     from ..... import TerminalInteractiveShell
            app = TerminalIPythonApp.instance()
            app.initialize()
            # import pyraf to write this shell obj to its namespace
diff --git a/setup.cfg b/setup.cfg
index 1603dc0..e71ece5 100644
--- a/setup.cfg
+++ b/setup.cfg
@@ -1,6 +1,6 @@
 [metadata]
 name = pyraf
-version = 2.1.5
+version = 2.1.6
 author = Rick White, Perry Greenfield
 author-email = help at stsci.edu
 home-page = http://www.stsci.edu/resources/software_hardware/pyraf
@@ -34,8 +34,6 @@ fail_message = If this is Windows, it is ok.
 [extension=pyraf.xutilmodule]
 sources = src/xutil.c
 libraries = X11
-optional = True
-fail_message = If this is Windows, it is ok.
 
 [global]
 setup_hooks = 
diff --git a/tools/createTarBall.csh b/tools/createTarBall.csh
index 072457a..04f0205 100755
--- a/tools/createTarBall.csh
+++ b/tools/createTarBall.csh
@@ -1,6 +1,6 @@
 #!/bin/csh -f
 #
-# $Id: createTarBall.csh 2045 2013-08-20 15:17:01Z sontag $
+# $Id: createTarBall.csh 2096 2013-11-25 19:44:14Z sontag $
 #
 
 if ($#argv != 3) then
@@ -117,7 +117,8 @@ endif
 # and generate the .tar.gz file
 cd $workDir/$pyr
 setenv PYRAF_NO_DISPLAY
-$pybin/python setup.py sdist >& $workDir/sdist.out
+# FORCE_USE_PY27... $pybin/python setup.py sdist >& $workDir/sdist.out
+/user/${USER}/info/usrlcl273/bin/python setup.py sdist >& $workDir/sdist.out
 if ($status != 0) then
    cat $workDir/sdist.out
    exit 1
@@ -154,7 +155,8 @@ if ("$junk" == "$verinfo2") then
    cd $workDir/$pyr
    /bin/rm -rf *.egg
    /bin/rm -rf dist
-   $pybin/python setup.py sdist >& $workDir/sdist2.out
+   # FORCE_USE_PY27... $pybin/python setup.py sdist >& $workDir/sdist2.out
+   /user/${USER}/info/usrlcl273/bin/python setup.py sdist >& $workDir/sdist2.out
    if ($status != 0) then
       cat $workDir/sdist2.out
       exit 1

diff --git a/lib/pyraf/ipython_api.py b/lib/pyraf/ipython_api.py
index ba71cc5..48405b6 100644
--- a/lib/pyraf/ipython_api.py
+++ b/lib/pyraf/ipython_api.py
@@ -6,7 +6,7 @@ attempting a more conventional IPython interpretation of a command.
 
 Code derived from pyraf.pycmdline.py
 
-$Id: ipython_api.py 1938 2013-03-05 19:50:53Z sontag $
+$Id: ipython_api.py 2120 2014-01-01 16:41:51Z sontag $
 """
 #*****************************************************************************
 #       Copyright (C) 2001-2004 Fernando Perez <fperez at colorado.edu>
@@ -16,18 +16,21 @@ $Id: ipython_api.py 1938 2013-03-05 19:50:53Z sontag $
 #*****************************************************************************
 from __future__ import division # confidence high
 
-OLD_IPY = True # "old" means prior to v0.12
+VERY_OLD_IPY = True # this means prior to v0.12
 try:
     from IPython.iplib import InteractiveShell
 except:
-    OLD_IPY = False
+    VERY_OLD_IPY = False
 
-if OLD_IPY:
+if VERY_OLD_IPY:
     from IPython import Release as release
     import IPython.ipapi as ipapi
 else:
     from IPython.core import release
-    import IPython.core.ipapi as ipapi
+    try:
+        import IPython.core.ipapi as ipapi
+    except:
+        ipapi = None # not available in v1.*
 
 __license__ = release.license
 
@@ -56,10 +59,15 @@ from pyraf.irafcompleter import IrafCompleter
 
 class IPythonIrafCompleter(IrafCompleter):
     import sys
-    if OLD_IPY:
+    if VERY_OLD_IPY:
         from IPython.iplib import InteractiveShell
     else:
-        from IPython.frontend.terminal.interactiveshell import TerminalInteractiveShell as InteractiveShell
+        try:
+            # location of "terminal" as of v1.1
+            from IPython.terminal.interactiveshell import TerminalInteractiveShell as InteractiveShell
+        except:
+            # location of "terminal" prior to v1.1
+            from IPython.frontend.terminal.interactiveshell import TerminalInteractiveShell as InteractiveShell
 
     def __init__(self, IP):
         IrafCompleter.__init__(self)
@@ -115,10 +123,15 @@ class IPython_PyRAF_Integrator(object):
     """
     import string
 
-    if OLD_IPY:
+    if VERY_OLD_IPY:
         from IPython.iplib import InteractiveShell
     else:
-        from IPython.frontend.terminal.interactiveshell import TerminalInteractiveShell as InteractiveShell
+        try:
+            # location of "terminal" as of v1.1
+            from IPython.terminal.interactiveshell import TerminalInteractiveShell as InteractiveShell
+        except:
+            # location of "terminal" prior to v1.1
+            from IPython.frontend.terminal.interactiveshell import TerminalInteractiveShell as InteractiveShell
 
 
     def __init__(self, clemulate=1, cmddict={},
@@ -141,7 +154,7 @@ class IPython_PyRAF_Integrator(object):
 
         self.traceback_mode = "Context"
 
-        if OLD_IPY:
+        if VERY_OLD_IPY:
             self._ipython_api = ipapi.get()
 
             self._ipython_magic = self._ipython_api.IP.lsmagic() # skip %
@@ -328,8 +341,10 @@ class IPython_PyRAF_Integrator(object):
 
         # get the color scheme from the user configuration file and pass
         # it to the trace formatter
-        ip = ipapi.get()
-        csm = ip.options['colors']
+        csm = 'Linux' # default
+        if ipapi:
+            ip = ipapi.get() # this works in vers prior to 1.*
+            csm = ip.options['colors']
 
         linecache.checkcache()
         tblist = traceback.extract_tb(tb)
@@ -348,7 +363,7 @@ class IPython_PyRAF_Integrator(object):
     def prefilter(self, IP, line, continuation):
         """prefilter pre-processes input to do PyRAF substitutions before
            passing it on to IPython.
            NOTE: this is ONLY used for OLD_IPY, since we use the transform
            hooks for the later versions.
         """
         line = self.cmd(str(line)) # use type str here, not unicode
@@ -426,7 +441,7 @@ __PyRAF = IPython_PyRAF_Integrator()
 # __PyRAF.use_pyraf_completer(feedback=fb) Can't do this yet...but it's hooked.
 # __PyRAF.use_pyraf_cl_emulation(feedback=fb)
 
-if OLD_IPY:
+if VERY_OLD_IPY:
     __PyRAF.use_pyraf_traceback(feedback=fb)
 else:
     if '-nobanner' not in sys.argv and '--no-banner' not in sys.argv:
@@ -348,7 +363,7 @@ class IPython_PyRAF_Integrator(object):
         """prefilter pre-processes input to do PyRAF substitutions before
            passing it on to IPython.
-           NOTE: this is ONLY used for OLD_IPY, since we use the transform
+           NOTE: this is ONLY used for VERY_OLD_IPY, since we use the transform
            hooks for the later versions.
         """
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-science/packages/python-pyraf.git



More information about the debian-science-commits mailing list